@@ -1,4 +1,4 @@
-'''20210904
+'''20210908
 '''
 import os
 import sys
@@ -61,6 +61,8 @@ class CodeQTSingals(qtc.QObject):
     dict_signal = qtc.pyqtSignal(dict)
     empty_signal = qtc.pyqtSignal()
     ndarray_signal = qtc.pyqtSignal(np.ndarray)
+    #20210908新增
+    bool_signale = qtc.pyqtSignal(bool)
 
 
 ###############################################
@@ -73,7 +75,6 @@ class CodeQTSingals(qtc.QObject):
 
 
 class UIWidget(qtw.QWidget):
-
     def __init__(self, widget_ui, objname="Form"):
         super().__init__(parent=None)
         # 根据objname的不同
@@ -111,7 +112,6 @@ class UIWidget(qtw.QWidget):
 
 
 class Window(qtw.QMainWindow):
-
     def __init__(self, myui):
         super().__init__(parent=None)
         if hasattr(myui, 'Ui_Form'):
@@ -133,8 +133,7 @@ class Window(qtw.QMainWindow):
         # 各种自定义信号
         self.codeqt_signals = CodeQTSingals()
         self.media_player = QMediaPlayer(self)
-        self.media_player.stateChanged.connect(
-            self.do_mediaplayer_statechanged)
+        self.media_player.stateChanged.connect(self.do_mediaplayer_statechanged)
         # 2021年8月21日03:40新增
         self.show_exec_flag = False
         # 2021年8月21日03:40新增
@@ -149,7 +148,6 @@ class Window(qtw.QMainWindow):
         this = self
 
         class MyThread(qtc.QThread):
-
             def __init__(self) -> None:
                 super().__init__()
 
@@ -369,7 +367,6 @@ class Window(qtw.QMainWindow):
         win = self
 
         class Canvas(qtw.QWidget):
-
             def __init__(self, parent) -> None:
                 super().__init__(parent=parent)
                 self.lastpoint = qtc.QPoint()
@@ -437,7 +434,6 @@ class Window(qtw.QMainWindow):
         20210901新增方法，可以在窗口书写文字
         '''
         class My_Inner_Widget(qtw.QWidget):
-
             def __init__(self, parent) -> None:
                 super().__init__(parent=parent)
                 self.font = qtg.QFont(font, size)
@@ -464,7 +460,6 @@ class Window(qtw.QMainWindow):
         20210901新增参数角度angle，默认值0
         '''
         class MyImage(qtw.QWidget):
-
             def __init__(self, parent) -> None:
                 super().__init__(parent=parent)
                 self.change_x = 0
